%  function KDR_sample()
%
%  Computing effective directions for regression with RKHS.
%
%  Author: Kenji Fukumizu
%  Affiliation: The Institute of Statistical Mathematics, ROIS
%  Date: Maarch 12, 2010
%  Version: 1.00
%
%  (C) Copyright:  Kenji Fukumizu
%

MAX_LOOP=50;    % Number of iterations in KDR method
EPS = 0.0001;   % Regularization parameter for matrix inversion.
ETA	= 10.0;     % range of the golden ratio search 
ANL	= 4;        % maximum value for anealing 
VERBOSE = 1;    % print the optimization process

fprintf('\nKDR> This is a sample program for the kernel dimensionality reduction\n');
fprintf('KDR> for regression\n');
fprintf('KDR> This program operates KDR for "wine data".\n');
fprintf('KDR>\n');
fprintf('KDR>   "wine.data" is a dataset from UCI repository. \n');
fprintf('KDR>   It is data for three class classificaiton \n');
fprintf('KDR>   with 13 dimensional input variables.\n');
fprintf('KDR>   In this sample, two dimensioal subspace is searched.\n');
fprintf('KDR>\n');

input('KDR> Press any key to continue  ');
fprintf('\n');
Data=dlmread('wine.data');

K=2;                % Dimension of Effective directions
L=3;                % Number of classes in wine data
M=length(Data(1,:))-L;  % Dimension of X
X=Data(:,1:M);      % X: input data
Y=Data(:,M+1:M+L);
N=length(X(:,1));   % Number of data
X=(X-repmat(mean(X),N,1))./repmat(std(X),N,1);   % standardization of X

% Gaussian kernels are used.  Deviation parameter are set by the median of
% mutual distances.   In the aneaning, sigma chages to 2*median to
% 0.5*median
sgx=0.5*MedianDist(X);   
sgy=MedianDist(Y);  % As Y is discrete, tuning is not necessary. 

% KDR optimization.  Steepest descent with line search
B=KernelDimRedTRG(X,Y,K,MAX_LOOP,sgx*sqrt(K/M),sgy,EPS,ETA,ANL,VERBOSE);
if( B==0 )
        fprintf('Error:  in KernelDimReduction()\n\n');
        return
end


% Plot data (2-dim and 3 classes)
fprintf('\nKDR> The projection of data onto the estiamted 2 dimensional \n');
fprintf('KDR> space is displayed\n');
Z=X*B;
RGN=max([max(abs(Z(:,1))), max(abs(Z(:,2)))])*1.2;
fxy = figure('Position',[0 400 300 300]);
axis([-RGN RGN -RGN RGN]);
axis square;
PlotData3class2dim(fxy,X,Y,B);

fprintf('KDR> KDR ended\n');
fprintf('KDR>\n');
input('KDR> Press any key to exit this program.  ');
clear all;
close all;
